<?php

namespace App\Http\Controllers;

use App\Services\EvoTalksService;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Http;

class EvoTalksController extends Controller
{
    protected $evoTalksService;

    public function __construct(EvoTalksService $evoTalksService)
    {
        $this->evoTalksService = $evoTalksService;
    }

    public function createOpportunity(Request $request)
    {
        $response = $this->evoTalksService->createOpportunityService($request->all());

        if ($response) {
            Log::info('Oportunidade criada com sucesso no EvoTalks', ['id' => $response['id'] ?? null]);
            return response()->json($response);
        }

        return response()->json([
            'error' => 'Erro ao criar oportunidade no EvoTalks',
        ], 500);
    }

    public function addNotesToOpportunity(Request $request)
    {
        $validated = $request->validate([
            'opportunity_id' => 'required|integer',
            'notes' => 'required|string',
        ]);

        $response = $this->evoTalksService->addNotesToOpportunity($validated['opportunity_id'], $validated['notes']);

        if ($response) {
            Log::info('Notas adicionadas com sucesso no EvoTalks', ['opportunity_id' => $validated['opportunity_id']]);
            return response()->json(['success' => true]);
        }

        return response()->json([
            'error' => 'Erro ao adicionar notas no EvoTalks',
        ], 500);
    }

    public function createTask(Request $request)
    {
        $response = $this->evoTalksService->createTaskService($request->all());

        if ($response) {
            Log::info('Tarefa criada com sucesso no EvoTalks', ['response' => $response]);
            return response()->json($response);
        }

        return response()->json([
            'error' => 'Erro ao criar tarefa no EvoTalks',
        ], 500);
    }

    public function markAsDone($taskId)
    {
        $response = $this->evoTalksService->markAsDoneService($taskId);

        if ($response) {
            Log::info('Tarefa marcada como concluída no EvoTalks', ['taskId' => $taskId]);
            return response()->json($response);
        }

        return response()->json([
            'error' => 'Erro ao marcar tarefa como concluída no EvoTalks',
        ], 500);
    }

    public function addContact($request)
    {
        $response = $this->evoTalksService->addContactService($request);

        if ($response) {
            Log::info('Contato criado com sucesso no EvoTalks', ['id' => $response['contactId'] ?? null]);
            return response()->json($response);
        }

        return response()->json([
            'error' => 'Erro ao criar contato no EvoTalks',
        ], 500);
    }
}
