<?php

namespace App\Services;

use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Log;

class EvoTalksService
{
    private $baseUrl;
    private $apiKey;
    private $queueId;

    public function __construct()
    {
        $this->apiKey = env('EVOTALKS_API_KEY');
        $this->baseUrl = env('EVOTALKS_BASE_URL');
        $this->queueId = env('EVOTALKS_API_QUEUEID');
    }

    private function apiHeaders()
    {
        return [
            'Accept' => 'application/json',
            'Content-Type' => 'application/json',
        ];
    }

    private function sendPostRequest($endpoint, $data)
    {
        $response = Http::withHeaders($this->apiHeaders())
            ->post("{$this->baseUrl}{$endpoint}", array_merge($data, [
                'queueId' => $this->queueId,
                'apiKey' => $this->apiKey,
            ]));

        if ($response->successful()) {
            return $response->json();
        }

        Log::error('Erro na requisição ao EvoTalks', [
            'endpoint' => $endpoint,
            'status' => $response->status(),
            'body' => $response->body(),
        ]);

        return null;
    }

    public function createOpportunityService($data)
    {
        return $this->sendPostRequest('/int/createOpportunity', $data);
    }

    public function addNotesToOpportunity($opportunityId, $notes)
    {
        return $this->sendPostRequest('/int/insertOpportunityNote', [
            'id' => $opportunityId,
            'note' => $notes,
        ]);
    }

    public function createTaskService($data)
    {
        return $this->sendPostRequest('/int/createTask', $data);
    }

    public function markAsDoneService($taskId)
    {
        return $this->sendPostRequest('/int/markAsDone', [
            'id' => $taskId,
            'userId' => 1,
        ]);
    }

    public function addContactService($contactData)
    {
        return $this->sendPostRequest('/int/addContact', $contactData);
    }
}
