<?php

namespace App\Helper;

use Exception;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Http;

class SlackNotifier
{
    public static function sendNotification(string $level, string $message, array $context = [])
    {
        try {
            $webHook = env('SLACK_URL');

            if (!$webHook) {
                Log::info('URL inválida ou não configurada');
                return;
            }

            if ($level == 'warning') {
                $color = '#DC1010'; // vermelho
            } else if ($level == 'info') {
                $color = '#36a64f'; // verde
            } else if ($level == 'crm') {
                $color = '#1D3ADA'; // Azul
            } else if ($level == 'controle') {
                $color = '#EEAD2D'; // amarelo
            } else if ($level == 'api4com') {
                $color = '#ADD8E6'; // azul claro
            }


            $payload = [
                'attachments' => [
                    [
                        'type' => 'section',
                        'color' => $color,
                        'fields' => [
                            [
                                'title' => 'Mensagem',
                                'value' => $message,
                                'short' => false
                            ],
                            [
                                'title' => 'Level',
                                'value' => strtoupper($level),
                                'short' => true
                            ],
                            [
                                'title' => 'Contexto:',
                                'value' => json_encode($context, JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE),
                                'short' => false
                            ]
                        ],
                        'footer' => 'Backend Log',
                        'ts' => time()
                    ],
                ],
            ];

            Http::post($webHook, $payload);
        } catch (Exception $th) {
            Log::error('Erro ao enviar notificação ao slack: ' . $th->getMessage());
        }
    }
}
