<?php

namespace App\Http\Controllers;

use App\Helper\SlackNotifier;
use App\Http\Controllers\EvoTalksController;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Log;

class Api4Controller extends Controller {
    protected $evoTalksController;
    protected $api4comToken;

    public function __construct(EvoTalksController $evoTalksController) {
        $this->evoTalksController = $evoTalksController;
        $this->api4comToken = env('API4COM_ACCESS_TOKEN');
    }

    public function api4comCall(Request $request) {
        $token = $request->input('metadata.api4comAccessToken');

        // if (!$token || $token !== $this->api4comToken) {
        //     SlackNotifier::sendNotification('api4com', 'Tentativa de acesso com token inválido.',
        //         [
        //             'provided_token' => $token,
        //             'expected_token' => $this->api4comToken,
        //             'request_data' => $request->all(),
        //         ]
        //     );

        //     return response()->json(['error' => 'Acesso Negado'], 403);
        // }
        
        Log::info("Chegou aqui!", [$request->input('called')]);
        
        $response = $request->input();
        $called = $response['called'] ?? null;
        $formatNumberCall = $this->formatNumber($called);
        SlackNotifier::sendNotification('api4com', 'Recebendo gravação do número: ', ['Número do cliente' => $formatNumberCall, 'Quem ligou?' => $response['caller']]);
        $searchValue = [
            "searchValue" => $formatNumberCall
        ];
    
        $findSearchValue = $this->evoTalksController->getContact($searchValue);
        
        if (!is_array($findSearchValue) || empty($findSearchValue['number'])) {
            Log::warning('Contato não possui um número válido', [$findSearchValue]);
            return response()->json(['error' => 'Contato não localizado'], 404);
        }
        
        if ($formatNumberCall == $findSearchValue['number']) {
            $this->evoTalksController->insertContactNotes($findSearchValue['id'], $this->note($response));
            Log::info("ID: ", [$findSearchValue['id']]);
            Log::info("Nota adicionada: ", [$this->note($response)]);
            return response()->json(['message' => 'Nota cadastrada com sucesso'], 201);
        }
    }

    public function formatNumber($callNumber) {
        $onlyNumber = preg_replace('/\D/', '', $callNumber);
        $formatedNumber = substr($onlyNumber, -11);
        
        return $formatedNumber;
    }
    
    public function note($response) {
        $agente = $this->agente($response['caller']);
        Log::info('Response: ', [$agente]);
        $note = "Agente {$agente} | Gravação da chamada: {$response['recordUrl']}";
        Log::info("Nota a ser cadastrada: {$note}");
        
        return $note;
    }
    
    public function agente($ramalAgente)
    {
        $agentes = [
            '1000' => 'Eder',
            '1001' => 'Gabrielle',
            '1003' => 'Felipe',
            '1004' => 'Dhiego',
            '1005' => 'Hugo',
            '1007' => 'Ana',
        ];

        return $agentes[$ramalAgente] ?? 'Desconhecido';
    }
}