<?php

namespace App\Http\Controllers;

use App\Services\ControleService;
use App\Services\GetLocCount;
use App\Helper\SlackNotifier;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Log;

class ControleController extends Controller
{
    protected $controleService;
    protected $getlocCount;

    public function __construct(ControleService $controleService, GetLocCount $getlocCount)
    {
        $this->controleService = $controleService;
        $this->getlocCount = $getlocCount;
    }

    public function receiveOpportunity(Request $request)
    {
        Log::info('Recebimento do Controle: ', ['JSON: ', $request->all()]);
        SlackNotifier::sendNotification('controle', 'Recebendo oportunidade do controle', [
            'imobiaCode' => $request->input('imobiaCode'),
            'name' => $request->input('name'),
            'expectedOperations' => $request->input('expectedOperations')
        ]);

        $validated = $request->validate([
            'imobiaCode'            => 'required|numeric',
            'name'                  => 'required|string',
            'document'              => 'nullable|string',
            'phoneNumber'           => 'required|string',
            'email'                 => 'nullable|email',
            'address'               => 'nullable|string',
            'houseNumber'           => 'nullable|string',
            'city'                  => 'nullable|string',
            'state'                 => 'nullable|string',
            'country'               => 'nullable|string',
            'postalCode'            => 'nullable|string',
            'modules'               => 'nullable|array',
            'expectedOperations'    => 'nullable|string',
            'value'                 => 'nullable|string',
        ]);

        Log::info('Dados validados!', [$validated]);
        return $this->controleService->receiveOpportunityService($validated);
    }

    public function countLocacao($idEmpresa)
    {
        return $this->controleService->countLocacaoService($idEmpresa);
    }

    public function getLocCount($codOpportunitiesList)
    {
        return $this->getlocCount->locCount($codOpportunitiesList);
    }
}
