<?php

namespace App\Http\Controllers;

use App\Helper\SlackNotifier;
use App\Services\EvoTalksService;
use App\Services\GetCodOpportunities;
use App\Services\UpdateOpportunittyProduct;
use App\Services\GetOpportunitiesStage;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Log;

class EvoTalksController extends Controller
{
    protected $evoTalksService;
    protected $getCodOpportunities;
    protected $updateOpportunittyProduct;
    protected $getOpportunitiesStage;

    public function __construct(
        EvoTalksService $evoTalksService,
        GetCodOpportunities $getCodOpportunities,
        UpdateOpportunittyProduct $updateOpportunittyProduct,
        GetOpportunitiesStage $getOpportunitiesStage
    ) {
        $this->evoTalksService              = $evoTalksService;
        $this->getCodOpportunities          = $getCodOpportunities;
        $this->updateOpportunittyProduct    = $updateOpportunittyProduct;
        $this->getOpportunitiesStage        = $getOpportunitiesStage;
    }

    public function createOpportunity(Request $request)
    {
        $response = $this->evoTalksService->createOpportunityService($request->all());

        if ($response) {
            SlackNotifier::sendNotification('info', 'Oportunidade criada com sucesso no EvoTalks pelo Pipedrive', ['id' => $response['id'] ?? null]);
            return response()->json($response);
        }

        return response()->json([
            'error' => 'Erro ao criar oportunidade no EvoTalks',
        ], 500);
    }

    public function addNotesToOpportunity(Request $request)
    {
        $validated = $request->validate([
            'opportunity_id' => 'required|integer',
            'notes' => 'required|string',
        ]);

        $response = $this->evoTalksService->addNotesToOpportunity($validated['opportunity_id'], $validated['notes']);

        if ($response) {
            SlackNotifier::sendNotification('info', 'Notas adicionadas com sucesso no EvoTalks', ['opportunity_id' => $validated['opportunity_id']]);
            return response()->json(['success' => true]);
        }

        return response()->json([
            'error' => 'Erro ao adicionar notas no EvoTalks',
        ], 500);
    }

    public function createTask(Request $request)
    {
        $response = $this->evoTalksService->createTaskService($request->all());

        if ($response) {
            return $response;
        }

        return response()->json([
            'error' => 'Erro ao criar tarefa no EvoTalks',
        ], 500);
    }

    public function markAsDone($taskId)
    {
        $response = $this->evoTalksService->markAsDoneService($taskId);

        if ($response) {
            Log::info('Tarefa marcada como concluída no EvoTalks', ['taskId' => $taskId]);
            return response()->json($response);
        }

        return response()->json([
            'error' => 'Erro ao marcar tarefa como concluída no EvoTalks',
        ], 500);
    }

    public function addContact($request)
    {
        return $this->evoTalksService->addContactService($request);
    }

    public function getContact($request)
    {
        return $this->evoTalksService->getContactService($request['searchValue']);
    }

    public function insertContactNotes($idContact, $note)
    {
        $insertContactNotesReq = [
            "id" => $idContact,
            "note" => $note
        ];

        $insertContactNotesService = $this->evoTalksService->insertContactNotesService($insertContactNotesReq);

        if ($insertContactNotesService) {
            return $insertContactNotesService;
        } else {
            return response()->json([
                'error' => 'Falha ao cadastrar a nota no contato'
            ], 500);
        }
    }
    public function getOpportunitiesStage(Request $request)
    {
        Log::info('tst', [$request->all()]);
        $stageId = $request->input('stageId');
        $title = $request->input('title');
        $mainphone = $request->input('mainphone');
        Log::info('getOppStg', [$stageId, $title, $mainphone]);
        return $this->getOpportunitiesStage->getOpportunitiesStage($stageId, $title, $mainphone);
    }

    public function getCodOpportunitiesFunnel()
    {
        return $this->getCodOpportunities->getProcessedOpportunities();
    }

    public function updateOpportunittyProduct($id, $qty, $expected)
    {
        return $this->updateOpportunittyProduct->updateProduct($id, $qty, $expected);
    }
}
