<?php

namespace App\Http\Middleware;

use Closure;
use Exception;
use Firebase\JWT\JWT;
use Firebase\JWT\Key;

class JwtAuthMiddleware
{
    public function handle($request, Closure $next)
    {
        $authorizationHeader = $request->header('Authorization'); // Obtém o cabeçalho Authorization

        if (!$authorizationHeader) {
            return response()->json(['message' => 'Token não fornecido'], 401);
        }

        if (!preg_match('/Bearer\s(\S+)/', $authorizationHeader, $matches)) {
            return response()->json(['message' => 'Formato de token inválido'], 401);
        }

        $token = $matches[1]; // Extrai o token do cabeçalho

        try {
            $decoded = JWT::decode($token, new Key(env('JWT_KEY'), 'HS256')); // Decodifica o token
            $request->user = $decoded; // Anexa os dados do token à requisição
        } catch (Exception $e) {
            return response()->json(['message' => 'Token inválido ou expirado'], 401);
        }

        return $next($request); // Permite a requisição continuar para a rota
    }
}
