<?php

namespace App\Services;

use App\Helper\SlackNotifier;
use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Log;

class CRMService
{
    private $baseUrl;
    private $apiKey;
    private $queueId;

    public function __construct()
    {
        $this->apiKey = env('EVOTALKS_API_KEY');
        $this->baseUrl = env('EVOTALKS_BASE_URL');
        $this->queueId = env('EVOTALKS_API_QUEUEID');
    }

    private function apiHeaders()
    {
        return [
            'Accept' => 'application/json',
            'Content-Type' => 'application/json',
        ];
    }

    private function sendPostRequest($endpoint, $data)
    {
        $response = Http::withHeaders($this->apiHeaders())
            ->post("{$this->baseUrl}{$endpoint}", array_merge($data, [
                'queueId' => $this->queueId,
                'apiKey' => $this->apiKey,
            ]));

        if ($response->successful()) {
            return $response->json();
        }

        Log::error('Erro na requisição ao EvoTalks', [
            'endpoint' => $endpoint,
            'status' => $response->status(),
            'body' => $response->body(),
        ]);

        return null;
    }

    public function sendWaTemplateService($number, $stageId, $variavel1)
    {
        try {
            Log::info('Iniciando envio de template', ['number' => $number, 'stageId' => $stageId]);

            if ($stageId == 16) {
                $templateId = 25;
            } else if ($stageId == 1) {
                $templateId = 23;
            } else if ($stageId == 34) {
                $templateId = 42;
            } else if ($stageId == 32) {
                $templateId = 43;
            } else if ($stageId == 6) {
                $templateId = 41;
            } else {
                return 'Template inválido';
            }

            $variavel = strlen($variavel1) === 0 ? "string" : $variavel1;
            if ($variavel && preg_match('/^([\d\w]+)\s*-\s*(.+)$/', trim($variavel), $matches)) {
                $variavel = $matches[2];
            }

            $sendTemplateBody = [
                "queueId" => $this->queueId,
                "apiKey" => $this->apiKey,
                "number" => (string) $number,
                "templateId" => $templateId,
                "data" => [
                    $variavel
                ],
                "userId" => 507,
                "country" => "BR",
                "markerId" => 0,
                "message" => "string",
                "cancelIfAlreadyOpen" => false,
                "openNewChat" => false
            ];

            $response = $this->sendPostRequest('/int/sendWaTemplate', $sendTemplateBody);

            if ($response) {
                SlackNotifier::sendNotification('crm', 'Template enviado com sucesso', ['cliente' => $sendTemplateBody['number']]);
                return response()->json(['message' => 'Template enviado com sucesso'], 201);
            }
        } catch (\Throwable $th) {
            SlackNotifier::sendNotification('warning', 'CRM - Falha ao enviar boas vindas', ['error' => $th->getMessage()]);
            return response()->json(['message' => 'CRM - Falha ao enviar boas-vindas', 'error' => $th->getMessage()], 500);
        }
    }

    public function newClientTagService($id)
    {
        try {
            Log::info('Atualizando a tag no cliente SelfService', ['client' => $id]);

            $newClientTagService = [
                "queueId" => $this->queueId,
                "apiKey" => $this->apiKey,
                "id" => $id,
                "tags" => [
                    38
                ]
            ];

            $response =  $this->sendPostRequest('/int/updateOpportunity', $newClientTagService);

            if ($response) {
                SlackNotifier::sendNotification('crm', 'Tag cadastrada com sucesso');
                return response()->json(['message' => 'Tag cadastrada com sucesso'], 201);
            }
        } catch (\Throwable $th) {
            SlackNotifier::sendNotification('warning', 'CRM - Falha ao definir tag', ['error' => $th->getMessage()]);
            return response()->json(['message' => 'CRM - Falha ao definir tag', 'error' => $th->getMessage()], 500);
        }
    }

    public function openNewChatService($number)
    {
        try {
            $data = [
                "queueId" => $this->queueId,
                "apiKey" => $this->apiKey,
                "number" => $number,
                "userId" => 513,
                "country" => "BR",
                "markerId" => 9,
                "message" => "teste"
            ];

            $response = Http::withHeaders($this->apiHeaders())
                ->get("{$this->baseUrl}/int/openChat", array_merge($data));

            if ($response) {
                SlackNotifier::sendNotification('crm', 'Chat iniciado');
                return response()->json(['message' => 'Chat iniciado'], 201);
            }
        } catch (\Throwable $th) {
            SlackNotifier::sendNotification('warning', 'CRM - Falha ao abrir chat', ['error' => $th->getMessage()]);
            return response()->json(['message' => 'CRM - Falha ao abrir chat', 'error' => $th->getMessage()], 500);
        }
    }
}
