<?php

namespace App\Services;

use App\Helper\DataMapper;
use App\Helper\TabelaPreco;
use App\Helper\SendPost;
use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Log;

class ControleService
{

    private $baseUrl;
    private $apikey;
    private $queueId;
    private $url_controle;
    private $apiKeyControle;
    protected $tabelaPreco;
    protected $dataMapper;
    protected $sendPost;

    public function __construct(TabelaPreco $tabelaPreco, DataMapper $dataMapper, SendPost $sendPost)
    {
        $this->apikey = (string) env('EVOTALKS_API_KEY');
        $this->baseUrl = (string) env('EVOTALKS_BASE_URL');
        $this->queueId = (int) env('EVOTALKS_API_QUEUEID');
        $this->url_controle = (string) env('URL_CONTROLE');
        $this->apiKeyControle = env('API_KEY_CONTROLE');
        $this->tabelaPreco = $tabelaPreco;
        $this->dataMapper = $dataMapper;
        $this->sendPost = $sendPost;
    }

    public function addContactService($contactData)
    {
        try {
            $response = $this->sendPost->sendPostRequest('/int/addContact', $contactData);

            if ($response) {
                return $response;
            }
        } catch (\Throwable $th) {
            return response()->json([
                'message' => 'Erro no cadastro do contato',
                'id' => $responseData['contactId'] ?? null,
                $th->getMessage()
            ], 500);
        }
    }

    public function receiveOpportunityService($validated)
    {
        try {
            Log::info('iniciando processamento', [$validated]);

            // Dados do contato
            $contactData = [
                'queueId'       => $this->queueId,
                'apiKey'        => $this->apikey,
                'name'          => $validated['imobiaCode'] . ' - ' . $validated['name'],
                'document'      => $validated['document'] ?? null,
                'number'        => $validated['phoneNumber'],
                'email'         => $validated['email'] ?? null,
                'address'       => $validated['address'] ?? null,
                'houseNumber'   => $validated['houseNumber'] ?? null,
                'city'          => $validated['city'] ?? null,
                'state'         => $validated['state'] ?? null,
                'country'       => $validated['country'] ?? null,
                'postalCode'    => $validated['postalCode'] ?? null,
                'tag'           => [1]
            ];

            Log::info('Processamento finalizado', [$contactData]);

            $contactResponse = $this->addContactService($contactData);

            if (!$contactResponse) {
                return response()->json(['error' => 'Erro ao cadastrar contato no EvoTalks'], 500);
            }

            Log::info('Preparando dados para envio', [$contactResponse]);

            // Dados da oportunidade
            $opportunityData = [
                'queueId'       => $this->queueId,
                'apiKey'        => $this->apikey,
                'fkPipeline'    => 3,
                'fkStage'       => 16,
                'responsableid' => 507,
                'title'         => $validated['imobiaCode'] . ' - ' . $validated['name'],
                'clientid'      => (string) $validated['imobiaCode'],
                'mainphone'     => $validated['phoneNumber'],
                'mainmail'      => $validated['email'] ?? '',
                'description'   => 'Módulos ativos: ' . implode(', ', $validated['modules']),
                'value'         => number_format($validated['value'] ?? 0, 2, '.', ''),
                'contacts'      => [$contactResponse['contactId']],
                'products'      => $validated['expectedOperations'] == 0 & $validated['value'] == 19.90 ? $this->dataMapper->mapProducts(1) : $this->dataMapper->mapProducts($validated['expectedOperations']),
            ];

            foreach ($opportunityData as $key => $value) {
                if (empty($value) && !is_numeric($value)) {
                    unset($opportunityData[$key]);
                }
            }

            Log::info('Cadastrando oportunidade no EvoTalks', ['data' => $opportunityData]);

            $response = $this->sendPost->sendPostRequest('/int/createOpportunity', $opportunityData);

            if ($response) {
                $responseData = $response;
                Log::info('Oportunidade criada com sucesso no EvoTalks pelo controle', ['id' => $responseData['id'] ?? null]);
                SlackNotifier::sendNotification('controle', 'Recebendo oportunidade do controle', [
                    'imobiaCode' => $validated['imobiaCode'],
                    'name' => $validated['name'],
                    'expectedOperations' => $validated['expectedOperations']
                ]);
                return response()->json($responseData, 201);
            }
        } catch (\Throwable $th) {
            return response()->json([
                'error' => 'Erro ao criar oportunidade no EvoTalks',
                $th->getMessage()
            ], 500);
        }
    }

    public function countLocacaoService($idEmpresa)
    {
        try {
            $url = "{$this->url_controle}/{$idEmpresa}/locacoes-ativas";

            $response = Http::withHeaders([
                'Accept' => 'application/json',
                'apiKey' => $this->apiKeyControle
            ])->get($url);

            if ($response) {
                return $response->json();;
            }
        } catch (\Throwable $th) {
            return response()->json([
                'error' => 'Erro ao buscar locações',
                'message' => $th->getMessage()
            ], 500);
        }
    }
}
