<?php

namespace App\Services;

use App\Helper\SendPost;
use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Log;

class EvoTalksService
{
    protected $sendPost;

    public function __construct(SendPost $sendPost)
    {
        $this->sendPost = $sendPost;
    }

    public function createOpportunityService($data)
    {
        return $this->sendPost->sendPostRequest('/int/createOpportunity', $data);
    }

    public function addNotesToOpportunity($opportunityId, $notes)
    {
        return $this->sendPost->sendPostRequest('/int/insertOpportunityNote', [
            'id' => $opportunityId,
            'note' => $notes,
        ]);
    }

    public function createTaskService($data)
    {
        return $this->sendPost->sendPostRequest('/int/createTask', $data);
    }

    public function markAsDoneService($taskId)
    {
        return $this->sendPost->sendPostRequest('/int/markAsDone', [
            'id' => $taskId,
            'userId' => 1,
        ]);
    }

    public function addContactService($contactData)
    {
        try {
            $response = $this->sendPost->sendPostRequest('/int/addContact', $contactData);
            
            if ($response) {
                SlackNotifier::sendNotification('info', 'Contato criado com sucesso no EvoTalks', ['id' => $response['contactId'] ?? null]);
                return $response['contactId'];
            }
        } catch (\Throwable $th) {
            return response()->json(['error' => 'Erro ao criar contato no EvoTalks',], 500);
        }
    }
    
    public function getContactService($getContact)
    {
        try {
            Log::info('Contato que chega: ', [$getContact]);
            $data = [
                "searchField" => "number",
                "searchValue" => "55".$getContact
            ];
            
            $response = $this->sendPost->sendPostRequest('/int/searchContact', $data);
            
            if (!$response || $response->status() === 404) {
                $data = [
                    "searchField" => "number",
                    "searchValue" => $getContact
                ];
                
                $response = $this->sendPost->sendPostRequest('/int/searchContact', $data);
                
                if (!$response || $response->status() === 404) {
                    Log::warning('Contato não localizado no Evotalks com 55', [$getContact]);
                    return null;
                }
            }
            
            $responseData = $response->json();
            
            if (empty($responseData) || !isset($responseData['number'])) {
            Log::warning('Resposta invlida do EvoTalks', [$responseData]);
            return null;
            }
    
            Log::info('Contato encontrado com sucesso no EvoTalks', ['Nmero' => $responseData['number']]);
        return $responseData;
        } catch (\Throwable $th) {
            return response()->json(['error' => 'Falha ao localizar o contato no EvoTalks'], 500);
        }
    }
    
    public function insertContactNotesService($insertContactNotes) 
    {
        Log::info("insertContactNotes: ", [$insertContactNotes]);
        $insertContactNotesService = $this->sendPost->sendPostRequest('/int/insertContactNote', $insertContactNotes);
        
        if ($insertContactNotesService) {
            return Log::info('insertContactNotesService ', [$insertContactNotesService]);
        }
    }
}
