<?php

namespace App\Services;

use App\Helper\SlackNotifier;
use App\Helper\SendPost;
use App\Http\Controllers\ControleController;
use App\Services\UpdateOpportunittyProduct;
use Illuminate\Support\Facades\Log;

class GetCodOpportunities
{
    private $webhookFunil;
    protected $sendPost;
    protected $controleController;
    protected $updateOpportunittyProduct;

    public function __construct(SendPost $sendPost, ControleController $controleController, UpdateOpportunittyProduct $updateOpportunittyProduct)
    {
        $this->sendPost = $sendPost;
        $this->controleController = $controleController;
        $this->updateOpportunittyProduct = $updateOpportunittyProduct;
        $this->webhookFunil = env('EVOTALKS_WEBHOOK_FUNIL');
    }

    public function getProcessedOpportunities()
    {
        $data = [
            'pipelineId' => 1
        ];

        $response = $this->sendPost->sendPostRequest('/int/getPipeOpportunities', $data);

        if ($response) {
            Log::info('Oportunidades do pipe 1 capturadas');
            $opportunities = $response;

            if (!is_array($opportunities)) {
                return response()->json(['error' => 'Resposta inválida da API'], 500);
            }

            $filteredData = $this->getIdAndImobiaCod($opportunities);
            $getLocCount = $this->controleController->getLocCount($filteredData);

            foreach ($getLocCount as $opportunity) {
                Log::info('Oportunidade a ser atualizada: ', $opportunity);
                $updatedProduct = $this->updateOpportunittyProduct->updateProduct(
                    $opportunity['id'],
                    $opportunity['qty'] ?? 0,
                    $opportunity['expected'] ?? 0
                );

                $this->calcChangeFunner($opportunity);

                $updatedProducts[] = $updatedProduct;
            }

            return response()->json($updatedProducts);
        } else {
            return response()->json(['error' => 'Erro ao buscar dados da API'], $response->status());
        }
    }


    private function getIdAndImobiaCod(array $opportunities)
    {
        $result = array_map(function ($item) {
            $imobia_cod = $item['title'];

            if ($imobia_cod && preg_match('/^([\d\w]+)\s*-/', trim($imobia_cod), $matches)) {
                $imobia_cod = $matches[1];
            }

            if ($imobia_cod && !ctype_digit($imobia_cod)) {
                SlackNotifier::sendNotification(
                    'controle',
                    'CRM - Oportunidade sem código',
                    [
                        'ID:' => $item['id'],
                        'Name' => $imobia_cod
                    ]
                );
            }

            return [
                'id' => $item['id'],
                'imobia_cod' => $imobia_cod
            ];
        }, $opportunities);

        return $result;
    }

    private function calcChangeFunner($opportunity)
    {
        if (!isset($opportunity['qty']) || !isset($opportunity['expected'])) {
            return $opportunity;
        }

        $qty = $opportunity['qty'];
        $expected = $opportunity['expected'];

        if ($expected == 0) {
            return $opportunity;
        }

        $percentage = ($qty / $expected) * 100;

        if ($percentage >= 80) {
            SlackNotifier::sendNotification(
                'info',
                'Oportunidade com mais de 80% da expectativa cadastrada',
                [
                    'imobiaCod'                 => $opportunity['imobia_cod'],
                    'Expectativa'               => $expected,
                    'Quantidade cadastrada'     => $qty,
                    'Porcentagem cadastrada'    => number_format($percentage, 2, ',', '.')
                ]
            );

            $this->sendPost->sendPostRequest($this->webhookFunil, ['opportunity_id' => $opportunity['id']]);
        } else {
            Log::info(
                'com menos de 80%',
                [
                    'Porcentagem cadastrada' => number_format($percentage, 2, ',', '.')
                ]
            );
        }

        return $opportunity;
    }
}
