<?php

namespace App\Services;

use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Log;

class ServiceMigrationPipeForEvo
{
    private $apikey;
    private $queueId;
    public function __construct()
    {
        $this->apikey = (string) env('EVOTALKS_API_KEY');
        $this->queueId = (int) env('EVOTALKS_API_QUEUEID');
    }
    public function migrateOpportunities()
    {

        $url = 'https://imobia.pipedrive.com/api/v2/deals';
        $apiToken = 'a385cd76027dd8817a20f8f1be86e28c1dff5dfe';
        $endpoint = 'https://imobiahost.com.br/pipe-talks/public/api/sync/pipedrive/create-opportunity';

        try {
            $response = Http::get($url, [
                'pipeline_id'   => 4,
                'status'        => 'open',
                'cursor'        => 'eyJmaWVsZCI6ImlkIiwiZmllbGRWYWx1ZSI6NzAxMSwic29ydERpcmVjdGlvbiI6ImFzYyIsImlkIjo3MDExfQ',
                'limit'         => 20,
                'api_token'     => $apiToken
            ]);

            Log::info("URL: ", [$response]);

            if ($response->failed()) {
                throw new \Exception('Erro ao buscar oportunidades do Pipedrive: ' . $response->body());
            }

            $opportunities = $response->json()['data'] ?? [];
            Log::info("Oportunidades: ", [$opportunities]);

            foreach ($opportunities as $opportunity) {

                $payload = [
                    'id'                  => $opportunity['id'] ?? null,
                    'title'               => $opportunity['title'] ?? null,
                    'value'               => $opportunity['value'] ?? 0,
                    'person_id'           => $opportunity['person_id'] ?? null,
                    'org_id'              => $opportunity['org_id'] ?? null,
                    'stage_id'            => $opportunity['stage_id'] ?? null,
                    'pipeline_id'         => $opportunity['pipeline_id'] ?? null,
                    'status'              => $opportunity['status'] ?? null,
                    'creator_user_id'     => $opportunity['creator_user_id'] ?? null,
                    'currency'            => $opportunity['currency'] ?? null,
                    'add_time'            => $opportunity['add_time'] ?? null,
                    'update_time'         => $opportunity['update_time'] ?? null,
                    'stage_change_time'   => $opportunity['stage_change_time'] ?? null,
                    'probability'         => $opportunity['probability'] ?? null,
                    'lost_reason'         => $opportunity['lost_reason'] ?? null,
                    'visible_to'          => $opportunity['visible_to'] ?? null,
                    'close_time'          => $opportunity['close_time'] ?? null,
                    'won_time'            => $opportunity['won_time'] ?? null,
                    'lost_time'           => $opportunity['lost_time'] ?? null,
                    'local_won_date'      => $opportunity['local_won_date'] ?? null,
                    'local_lost_date'     => $opportunity['local_lost_date'] ?? null,
                    'local_close_date'    => $opportunity['local_close_date'] ?? null,
                    'expected_close_date' => $opportunity['expected_close_date'] ?? null,
                    'owner_id'            => $opportunity['owner_id'] ?? null,
                    'custom_fields'       => $opportunity['custom_fields'] ?? null,
                    'label_ids'           => $opportunity['label_ids'] ?? [],
                    'is_deleted'          => $opportunity['is_deleted'] ?? false,
                    'origin'              => $opportunity['origin'] ?? null,
                    'origin_id'           => $opportunity['origin_id'] ?? null,
                    'channel'             => $opportunity['channel'] ?? null,
                    'channel_id'          => $opportunity['channel_id'] ?? null,
                    'acv'                 => $opportunity['acv'] ?? null,
                    'arr'                 => $opportunity['arr'] ?? null,
                    'mrr'                 => $opportunity['mrr'] ?? null
                ];


                Log::info("Oportunidade separada: ", [$payload]);

                $postResponse = Http::post($endpoint, $payload);

                if ($postResponse->failed()) {
                    Log::error("Erro ao migrar oportunidade", [
                        'oportunidade' => $opportunity,
                        'erro'         => $postResponse->body()
                    ]);
                } else {
                    Log::info("Oportunidade migrada com sucesso", ['id' => $opportunity['id']]);
                }

                echo `Oportunidade {$payload['title']} cadastrada!`;
            }

            echo "Migração concluída!";
        } catch (\Exception $e) {
            Log::error("Erro durante a migração", ['message' => $e->getMessage()]);
            echo "Erro durante a migração: " . $e->getMessage();
        }
    }
}
