<?php

namespace App\Services;

use App\Helper\DataMapper;
use App\Http\Controllers\EvoTalksController;
use Illuminate\Support\Facades\Log;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Http;

class syncPipeDriveActivitiesToEvoTalks {
    protected $dataMapper;
    protected $evoTalksController;

    public function __construct(DataMapper $dataMapper, EvoTalksController $evoTalksController) {
        $this->dataMapper = $dataMapper;
        $this->evoTalksController = $evoTalksController;
    }

    public function syncPipeDriveActivitiesToEvoTalks($activity, $opportunityId)
    {
        if (!isset($activity['data']['type'])) {
            Log::warning('Atividade sem tipo definido', ['activity' => $activity['data']['type']]);
            return;
        }

        $data = [
            'owner'         => 507,
            'title'         => $activity['data']['subject'] ?? 'Sem título',
            'description'   => $activity['data']['note'] ?? 'Sem descrição',
            'duedate'       => $activity['data']['due_date'] ?? null,
            'fkOpportunity' => $opportunityId,
            'progress'      => 0,
            'action'        => $this->dataMapper->mapPipeDriveTypeToEvotalksAction($activity['data']['type']) ?? 0,
            'actiondata'    => '',
            'checklist'     => [],
            'watchers'      => [],
            'contacts'      => [],
            'users'         => [1],
            'files'         => [],
            'tags'          => [],
        ];

        try {
            $taskResponse = $this->evoTalksController->createTask(new Request($data));
            Log::info('Resposta da criação da tarefa', ['taskResponse' => $taskResponse]);

            if (isset($activity['data']['done']) && $activity['data']['done'] === true) {
                $this->evoTalksController->markAsDone($taskResponse['id']);
            }
        } catch (\Exception $e) {
            Log::error('Erro ao sincronizar atividade com EvoTalks', ['error' => $e->getMessage()]);
        }
    }
}