<?php

namespace App\Services;

use App\Helper\SlackNotifier;
use App\Helper\TabelaPreco;
use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Log;

class UpdateOpportunittyProduct
{
    private $baseUrl;
    private $apiKey;
    private $queueId;
    protected $tabelaPreco;

    public function __construct(TabelaPreco $tabelaPreco)
    {
        $this->apiKey = env('EVOTALKS_API_KEY');
        $this->baseUrl = env('EVOTALKS_BASE_URL');
        $this->queueId = env('EVOTALKS_API_QUEUEID');
        $this->tabelaPreco = $tabelaPreco;
    }

    private function apiHeaders()
    {
        return [
            'Accept' => 'application/json',
            'Content-Type' => 'application/json',
        ];
    }

    private function sendPostRequest($endpoint, $data)
    {
        $response = Http::withHeaders($this->apiHeaders())
            ->post("{$this->baseUrl}{$endpoint}", array_merge($data, [
                'queueId' => $this->queueId,
                'apiKey' => $this->apiKey,
            ]));

        if ($response->successful()) {
            return $response->json();
        }

        Log::error('Erro na requisição ao EvoTalks', [
            'endpoint' => $endpoint,
            'status' => $response->status(),
            'body' => $response->body(),
        ]);

        return null;
    }

    public function updateProduct($id, $qty, $expected)
    {
        try {
            $products = [];
            $products[0] = [
                'id' => $this->tabelaPreco->getTaxaOperacao($expected)['id'],
                'qty' => $expected,
                'discount' => 0
            ];

            $products[1] = [
                'id' => 2,
                'qty' => $qty,
                'discount' => 0
            ];

            $data = [
                'queueId'   => $this->queueId,
                'apikey'    => $this->apiKey,
                'id'        => $id,
                'tags'      => [27],
                'products'  => $products

            ];

            $response = $this->sendPostRequest('/int/updateOpportunity', $data);

            if ($response) {
                return response()->json(['message' => 'Quantidade de locações atualizada com sucesso'], 201);
            }
        } catch (\Throwable $th) {
            SlackNotifier::sendNotification('warning', 'CRM - Falha ao atualizar quantidade de locações', ['error' => $th->getMessage()]);
            return response()->json(['message' => 'CRM - Falha ao atualizar quantidade de locações', 'error' => $th->getMessage()], 500);
        }
    }
}
